==> webkitgtk-1.10.0.tar.xz: webkitgtk-1.10.0/Source/WebCore/loader/cache/CachedShader.cpp <==
/*
 * Copyright (C) 2011 Adobe Systems Incorporated. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer.
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials
 *    provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include "config.h"

#if ENABLE(CSS_SHADERS)

#include "CachedShader.h"
#include "MemoryInstrumentation.h"
#include "SharedBuffer.h"
#include "TextResourceDecoder.h"
#include <wtf/text/StringBuilder.h>

namespace WebCore {

CachedShader::CachedShader(const ResourceRequest& resourceRequest)
    : CachedResource(resourceRequest, ShaderResource)
    , m_decoder(TextResourceDecoder::create("application/shader"))
{
}

CachedShader::~CachedShader()
{
}

const String& CachedShader::shaderString()
{
    if (m_shaderString.isNull() && m_data) {
        StringBuilder builder;
        builder.append(m_decoder->decode(m_data->data(), m_data->size()));
        builder.append(m_decoder->flush());
        m_shaderString = builder.toString();
    }

    return m_shaderString;
}

void CachedShader::data(PassRefPtr<SharedBuffer> data, bool allDataReceived)
{
    if (allDataReceived)
        m_data = data;
    CachedResource::data(data, allDataReceived);
}

void CachedShader::reportMemoryUsage(MemoryObjectInfo* memoryObjectInfo) const
{
    MemoryClassInfo info(memoryObjectInfo, this, MemoryInstrumentation::CachedResourceShader);
    CachedResource::reportMemoryUsage(memoryObjectInfo);
    info.addMember(m_decoder);
    info.addInstrumentedMember(m_shaderString);
}

} // namespace WebCore

#endif // ENABLE(CSS_SHADERS)

==> webkitgtk_1.11.91.orig.tar.xz: webkitgtk-1.11.91/Source/WebCore/loader/cache/CachedShader.cpp <==
/*
 * Copyright (C) 2011 Adobe Systems Incorporated. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer.
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials
 *    provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER “AS IS” AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include "config.h"

#if ENABLE(CSS_SHADERS)

#include "CachedShader.h"
#include "ResourceBuffer.h"
#include "TextResourceDecoder.h"
#include "WebCoreMemoryInstrumentation.h"
#include <wtf/text/StringBuilder.h>

namespace WebCore {

CachedShader::CachedShader(const ResourceRequest& resourceRequest)
    : CachedResource(resourceRequest, ShaderResource)
    , m_decoder(TextResourceDecoder::create("application/shader"))
{
}

CachedShader::~CachedShader()
{
}

const String& CachedShader::shaderString()
{
    if (m_shaderString.isNull() && m_data) {
        StringBuilder builder;
        builder.append(m_decoder->decode(m_data->data(), m_data->size()));
        builder.append(m_decoder->flush());
        m_shaderString = builder.toString();
    }

    return m_shaderString;
}

void CachedShader::data(PassRefPtr<ResourceBuffer> data, bool allDataReceived)
{
    if (allDataReceived)
        m_data = data;
    CachedResource::data(data, allDataReceived);
}

void CachedShader::reportMemoryUsage(MemoryObjectInfo* memoryObjectInfo) const
{
    MemoryClassInfo info(memoryObjectInfo, this, WebCoreMemoryTypes::CachedResourceShader);
    CachedResource::reportMemoryUsage(memoryObjectInfo);
    info.addMember(m_decoder, "decoder");
    info.addMember(m_shaderString, "shaderString");
}

} // namespace WebCore

#endif // ENABLE(CSS_SHADERS)
